<!-- Reference links -->

  [rpo]: https://en.wikipedia.org/wiki/Recovery_point_objective
  [rto]: https://en.wikipedia.org/wiki/Recovery_time_objective
  [repmgr]: https://www.repmgr.org/
  [sqldump]: https://www.postgresql.org/docs/current/static/backup-dump.html
  [physicalbackup]: https://www.postgresql.org/docs/current/static/backup-file.html
  [pitr]: https://www.postgresql.org/docs/current/static/continuous-archiving.html
  [adminbook]: https://www.2ndquadrant.com/en/books/postgresql-10-administration-cookbook/
  [wal]: https://www.postgresql.org/docs/current/static/wal.html
  [49340627f9821e447f135455d942f7d5e96cae6d]: https://git.postgresql.org/gitweb/?p=postgresql.git;a=commit;h=49340627f9821e447f135455d942f7d5e96cae6d
  [requirements_recovery]: https://www.postgresql.org/docs/current/static/warm-standby.html#STANDBY-PLANNING
  [yumpgdg]: https://yum.postgresql.org/
  [aptpgdg]: https://apt.postgresql.org/
  [aptpgdgwiki]: https://wiki.postgresql.org/wiki/Apt
  [epel]: https://fedoraproject.org/wiki/EPEL
  [man5]: https://docs.pgbarman.org/barman.5.html
  [setup_user]: https://docs.python.org/3/install/index.html#alternate-installation-the-user-scheme
  [pypi]: https://pypi.python.org/pypi/barman/
  [pgpass]: https://www.postgresql.org/docs/current/static/libpq-pgpass.html
  [pghba]: https://www.postgresql.org/docs/current/static/client-authentication.html
  [authpghba]: https://www.postgresql.org/docs/current/static/auth-pg-hba-conf.html
  [streamprot]: https://www.postgresql.org/docs/current/static/protocol-replication.html
  [roles]: https://www.postgresql.org/docs/current/static/role-attributes.html
  [replication-slots]: https://www.postgresql.org/docs/current/static/warm-standby.html#STREAMING-REPLICATION-SLOTS
  [synch]: https://www.postgresql.org/docs/current/static/warm-standby.html#SYNCHRONOUS-REPLICATION
  [target]: https://www.postgresql.org/docs/current/static/runtime-config-wal.html#RUNTIME-CONFIG-WAL-RECOVERY-TARGET
  [2ndqrpmrepo]: https://rpm.2ndquadrant.com/
  [2ndqdebrepo]: https://apt.2ndquadrant.com/
  [boto3]: https://github.com/boto/boto3
  [boto3creds]: https://boto3.amazonaws.com/v1/documentation/api/latest/guide/configuration.html
  [azure-identity]: https://docs.microsoft.com/en-us/python/api/azure-identity/?view=azure-python
  [azure-storage-blob]: https://docs.microsoft.com/en-us/python/api/azure-storage-blob/?view=azure-python
  [azure-storage-auth]: https://docs.microsoft.com/en-us/azure/storage/blobs/authorize-data-operations-cli#set-environment-variables-for-authorization-parameters
  [google-cloud-storage]: https://cloud.google.com/storage/docs/reference/libraries
  [pg_basebackup-documentation]: https://www.postgresql.org/docs/current/app-pgbasebackup.html
  [pg-backup-api]: https://github.com/EnterpriseDB/pg-backup-api
  [config-options]: https://docs.pgbarman.org/barman.5.html#options
  [barman-downloads]: https://pgbarman.org/downloads/
  [python-2-sunset]: https://www.python.org/doc/sunset-python-2/
  [psql]: https://www.postgresql.org/docs/current/app-psql.html
  [snapshot-recovery-runbook-azure]: https://github.com/EnterpriseDB/barman/blob/master/doc/runbooks/snapshot_recovery_azure.md
  [snapshot-recovery-script]: https://github.com/EnterpriseDB/barman/blob/master/scripts/prepare_snapshot_recovery.py
  [postgres-low-level-base-backup]: https://www.postgresql.org/docs/current/continuous-archiving.html#BACKUP-LOWLEVEL-BASE-BACKUP
  [pgbarman-barman-cloud-backup-show]: https://docs.pgbarman.org/release/latest/barman-cloud-backup-show.1.html

  [8]: https://en.wikipedia.org/wiki/Hard_link
  [11]: https://www.pgbarman.org/
  [12]: https://www.pgbarman.org/support/
  [13]: https://www.enterprisedb.com/
  [14]: https://www.pgbarman.org/faq/
  [15]: https://blog.2ndquadrant.com/tag/barman/
  [16]: https://github.com/hamann/check-barman
  [17]: https://github.com/2ndquadrant-it/puppet-barman
  [18]: https://4caast.morfeo-project.org/
  [20]: https://www.postgresql.org/docs/current/static/functions-admin.html
  [24]: https://www.postgresql.org/docs/current/static/warm-standby.html#STREAMING-REPLICATION
  [25]: https://www.postgresql.org/docs/current/static/app-pgreceivewal.html
  [26]: https://goo.gl/218Ghl
  [27]: https://github.com/emin100/barmanapi

  [31]: https://www.postgresql.org/
